@@ -59,6 +59,7 @@ import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.io.PrintStream;
 import java.io.Writer;
+import java.nio.charset.StandardCharsets;
 import java.rmi.RemoteException;
 import java.util.HashMap;
 import java.util.Map;
@@ -535,7 +536,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         @Override
         public void run() {
             try {
-                InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
+                InputStreamReader inputStreamReader = new InputStreamReader(inputStream, StandardCharsets.UTF_8);
                 BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
                 String line = null;
                 StringBuilder builder = new StringBuilder();
