@@ -82,6 +82,14 @@ public enum GuardProperty {
      * Maximum lifetime of an authentication-token.
      */
     authLifeTime("1W"),
+    /**
+     * Autocrypt enabled
+     */
+    autoCryptEnabled(true),
+    /**
+     * Autocrypt outgoing prefer-encrypt set to mutual
+     */
+    autoCryptMutual(true),
     /**
      * Defines how long someone will be locked out after bad attempts.
      * Defaults to 10 minutes
@@ -545,6 +553,22 @@ public enum GuardProperty {
      * The trust level for keys fetched from HKP servers queried via DNSSEC protected SRV DNS record
      */
     trustLevelHKPSRVDNSSECServer(4, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust for keys generated by incoming autocrypt headers
+     */
+    trustLevelAutoCrypt(2, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust for keys generated by incoming autocrypt headers AND manual verified by the user
+     */
+    trustLevelAutoCryptUserVerified(5, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust for keys fetched from a WKS server
+     */
+    trustLevelWKSServer(3, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys fetched from WKS servers queried via DNSSEC protected SRV DNS record
+     */
+    trustLevelWKSSRVDNSSECServer(4, GuardProperty.PREFIX + "keySources."),
     /**
      * Defines the version of the 'Upgrader'
      */
