@@ -78,6 +78,7 @@ import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.database.dao.SchemaCandidate;
 import com.openexchange.guard.database.exception.GuardDatabaseExceptionCodes;
 import com.openexchange.guard.database.osgi.DBMigrationServiceTracker;
+import com.openexchange.guard.database.update.shardUpdate.ShardUpdaterService;
 import com.openexchange.guard.database.utils.DBUtils;
 
 /**
@@ -99,15 +100,18 @@ public class GuardShardingServiceImpl implements GuardShardingService {
 
     private final DatabaseMaintenanceService databaseMaintenanceService;
 
+    private final ShardUpdaterService updateService;
+
     /**
      * Initialises a new {@link GuardShardingServiceImpl}.
      *
      * @param databaseMaintenanceService
      */
-    public GuardShardingServiceImpl(GuardDatabaseService guardDatabaseService, DBMigrationExecutorService dbMigrationExecutorService, DatabaseMaintenanceService databaseMaintenanceService) {
+    public GuardShardingServiceImpl(GuardDatabaseService guardDatabaseService, DBMigrationExecutorService dbMigrationExecutorService, DatabaseMaintenanceService databaseMaintenanceService, ShardUpdaterService updateService) {
         this.dbMigrationExecutorService = dbMigrationExecutorService;
         this.guardDatabaseService = guardDatabaseService;
         this.databaseMaintenanceService = databaseMaintenanceService;
+        this.updateService = updateService;
     }
 
     @Override
@@ -283,13 +287,9 @@ public class GuardShardingServiceImpl implements GuardShardingService {
         }
     }
 
-    /**
-     * Returns all guard shards that are registered within the configdb.
-     *
-     * @return {@link List} with the shard identifiers
-     * @throws OXException
-     */
-    private List<Integer> getAllShards() throws OXException {
+
+    @Override
+    public List<Integer> getAllShards() throws OXException {
         List<Integer> shardIds = new ArrayList<>();
 
         String shardBaseName = Services.getService(GuardConfigurationService.class).getProperty(GuardProperty.dbSchemaBaseName);
@@ -340,5 +340,9 @@ public class GuardShardingServiceImpl implements GuardShardingService {
             candidate.finish();
         }
         updateShardSchema(shard);
+
+        // Perform any updates in the updateService
+        updateService.doUpdates(shard);
+
     }
 }
