@@ -356,7 +356,7 @@ public class GuardGuestServiceImpl implements GuardGuestService {
             return Collections.emptyList();
         }
         List<FileCacheItem> itemsForUser =
-            fileCacheStorage.getForUser(user.getId(), DEFAULT_PAGING_OFFSET, DEFAULT_PAGING_SIZE);
+            fileCacheStorage.getForUser(user.getId(), user.getContextId(), DEFAULT_PAGING_OFFSET, DEFAULT_PAGING_SIZE);
         return itemsForUser.stream().map(item -> item.getItemId()).collect(Collectors.toList());
     }
 
@@ -456,7 +456,7 @@ public class GuardGuestServiceImpl implements GuardGuestService {
         Objects.requireNonNull(guestUser.getOXGuardUser(), "OXGuardUser must not ne null");
 
         List<FileCacheItem> itemsForUser =
-            fileCacheStorage.getForUser(guestUser.getOXGuardUser().getId(), DEFAULT_PAGING_OFFSET, DEFAULT_PAGING_SIZE);
+            fileCacheStorage.getForUser(guestUser.getOXGuardUser().getId(), guestUser.getOXGuardUser().getContextId(), DEFAULT_PAGING_OFFSET, DEFAULT_PAGING_SIZE);
         return itemsForUser.stream().map(fileCacheItem -> fileCacheItem.getItemId()).collect(Collectors.toList());
     }
 
