@@ -188,7 +188,7 @@ public class GuestConverterServiceImpl implements GuestConverterService {
     private String beginConversion (UserIdentity userIdentity, String origLinkId) throws OXException {
         String newLinkId = origLinkId;
         // Get a list of all items in the fileCacheStorage
-        List<FileCacheItem> items = fileCacheStorage.findAllForUser(userIdentity.getOXGuardUser().getId());
+        List<FileCacheItem> items = fileCacheStorage.findAllForUser(userIdentity.getOXGuardUser().getId(), userIdentity.getOXGuardUser().getContextId());
         for (FileCacheItem item: items) {
             if (doConvert (userIdentity, item.getItemId())) {  // Check if the item requires conversion
                 if (convert(userIdentity, item.getItemId(), newItemId(item.getItemId()))) {
@@ -208,7 +208,9 @@ public class GuestConverterServiceImpl implements GuestConverterService {
     @Override
     public String doUpgrade(String itemId, UserIdentity userIdentity, String language) throws OXException {
         String url = guestRedirectorService.getRedirect(userIdentity.getOXGuardUser().getId(), userIdentity.getOXGuardUser().getContextId());
-        if (url != null) return url;
+        if (url != null) {
+            return url;
+        }
         ///// Do upgrade
         if (this.converters == null || this.converters.length == 0) {
             throw GuardGuestExceptionCodes.MISSING_REQUIRED_CONVERTERS.create();
