@@ -16,8 +16,6 @@ import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.hkpclient.osgi.Services;
-import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
 import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
 
 /**
@@ -91,6 +89,7 @@ public class HKPClient {
         RequestConfig requestConfig = RequestConfig.custom()
             .setConnectTimeout(connectionTimeout)
             .setSocketTimeout(connectionTimeout)
+            .setRedirectsEnabled(false)
             .build();
         return HttpClientBuilder.create().setDefaultRequestConfig(requestConfig).build();
     }
@@ -103,11 +102,11 @@ public class HKPClient {
      * @throws OXException
      */
     private String doRequest(String url, int timeout) throws OXException {
-        if (timeout <= 0) return null;  // Already timed out
-        if(url.startsWith(HKP)) {
+        if (timeout <= 0)
+            return null;  // Already timed out
+        if (url.startsWith(HKP)) {
             url = url.replace(HKP, HTTP);
-        }
-        else if(url.startsWith(HKPS)) {
+        } else if (url.startsWith(HKPS)) {
             url = url.replace(HKPS, HTTPS);
         }
         HttpClient httpClient = getClient(timeout);
@@ -204,11 +203,11 @@ public class HKPClient {
         for (String line : lines) {
             // Get count of keys
             /*
-            if (line.startsWith("info")) {
-                int i = line.lastIndexOf(":");
-                String count = line.substring(i + 1).trim();
-            }
-            */
+             * if (line.startsWith("info")) {
+             * int i = line.lastIndexOf(":");
+             * String count = line.substring(i + 1).trim();
+             * }
+             */
             if (line.startsWith("pub")) {
                 String[] data = line.split(":");
                 pub = data[1].trim();
