@@ -1,11 +1,8 @@
 
 package com.openexchange.guard.hkpclient.services;
 
-import java.time.Duration;
-import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.concurrent.TimeUnit;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -113,7 +110,7 @@ public class RemoteHKPClientService implements HKPClientService, Reloadable  {
     }
 
     private RemoteKeyResult findInternal (String clientToken, Long id, String email, int timeout) throws Exception {
-        String search = "0x" + LongUtil.longToHexString(id);
+        String search = LongUtil.longToHexString(id);
         TimeTracker timer = new TimeTracker(timeout);
         PGPPublicKeyRing ring = findById (clientToken, configuredRemoteHKPServers, search, timeout);
         if (ring != null) {
