@@ -1,9 +1,6 @@
 
 package com.openexchange.guard.hkpclient.services;
 
-import java.time.Duration;
-import java.time.Instant;
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import org.bouncycastle.openpgp.PGPPublicKey;
@@ -20,6 +17,7 @@ import com.openexchange.guard.hkpclient.client.HKPClient;
 import com.openexchange.guard.hkpclient.client.HKPClient.TLSMODE;
 import com.openexchange.guard.hkpclient.osgi.Services;
 import com.openexchange.guard.hkpclient.util.TimeTracker;
+import com.openexchange.guard.inputvalidation.DomainNameValidator;
 
 /**
  *
@@ -30,17 +28,17 @@ import com.openexchange.guard.hkpclient.util.TimeTracker;
  */
 public class SRVHKPClientService implements HKPClientService {
 
-    private static final Logger                       logger            = LoggerFactory.getLogger(SRVHKPClientService.class);
-    private static final Collection<PGPPublicKeyRing> EMPTY_LIST        = Collections.emptyList();
-    private static final String                       HKPS_SERVICE_NAME = "_hkps._tcp.";
-    private static final String                       HKP_SERVICE_NAME  = "_hkp._tcp.";
-    private final HKPClientService                    delegate;
-    private final boolean                             forceTLS;
+    private static final Logger logger = LoggerFactory.getLogger(SRVHKPClientService.class);
+    private static final Collection<PGPPublicKeyRing> EMPTY_LIST = Collections.emptyList();
+    private static final String HKPS_SERVICE_NAME = "_hkps._tcp.";
+    private static final String HKP_SERVICE_NAME = "_hkp._tcp.";
+    private final HKPClientService delegate;
+    private final boolean forceTLS;
 
     private class QueryResult {
 
         private final Collection<PGPPublicKeyRing> result;
-        private final ValidationResult             validationResult;
+        private final ValidationResult validationResult;
 
         public QueryResult(Collection<PGPPublicKeyRing> result, ValidationResult validationResult) {
             this.result = Collections.unmodifiableCollection(result);
@@ -111,10 +109,12 @@ public class SRVHKPClientService implements HKPClientService {
             if (target.endsWith(".")) {
                 target = target.substring(0, target.length() - 1);
             }
-            int port = nextcheck.getPort();
-            rings = new HKPClient(clientToken, isForceTLS(serviceName) ? TLSMODE.TLS : TLSMODE.BY_PORT).findKeys(target, port, email, timeout);
-            if (rings != null) {
-                return new QueryResult(rings, result.getValidationResult());
+            if (new DomainNameValidator().isValid(target) && !DomainNameValidator.isLocalAddress(target)) {  // Confirm target is a proper domain name
+                int port = nextcheck.getPort();
+                rings = new HKPClient(clientToken, isForceTLS(serviceName) ? TLSMODE.TLS : TLSMODE.BY_PORT).findKeys(target, port, email, timeout);
+                if (rings != null) {
+                    return new QueryResult(rings, result.getValidationResult());
+                }
             }
             current = nextcheck.getPriority();
         }
