@@ -56,7 +56,7 @@ import java.security.PublicKey;
 import java.security.interfaces.RSAPublicKey;
 import java.security.spec.InvalidKeySpecException;
 import java.security.spec.X509EncodedKeySpec;
-import java.sql.Date;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.Locale;
 import org.apache.commons.codec.binary.Base64;
@@ -90,7 +90,7 @@ public class GuardKeys {
     private boolean passwordNeeded;
     private int userid;
     private int contextid;
-    private Date lastup;
+    private java.util.Date lastup;
     private String misc;
     private JsonObject settings;
     private String email;
