@@ -64,14 +64,17 @@ public class OGPGPKeyRing {
     private boolean inline;
     private final String ids;
     private boolean guardKey;
-    private final boolean owned; //true, if this key is owned by the user/caller, false if it was shared by another user
+    private boolean owned; //true, if this key is owned by the user/caller, false if it was shared by another user
+    private boolean verified;  // user verified key, used in autocrypt
 
     /**
      * Initializes a new {@link OGPGPKeyRing}.
      *
+     * @param ids The uniqe IDs string of the {@link OGPGPKeyRing}
      * @param publicKeyRing The PGP key ring
      * @param isInline Whether the key is marked as "inline" or not
      * @param shareLevel The share level of the key
+     * @param owned Whether this key is owned by the caller/creater/context requesting it
      */
     public OGPGPKeyRing(String ids, PGPPublicKeyRing publicKeyRing, boolean isInline, int shareLevel, boolean owned) {
         this.ids = ids;
@@ -91,6 +94,16 @@ public class OGPGPKeyRing {
         this.guardKey = guardKey;
     }
 
+    public OGPGPKeyRing(String ids, PGPPublicKeyRing publicKeyRing, boolean guardKey, boolean verified) {
+        this.ids = ids;
+        this.keyRing = publicKeyRing;
+        this.inline = false;
+        this.shareLevel = 0;
+        this.owned = true;
+        this.guardKey = guardKey;
+        this.verified = verified;
+    }
+
     /**
      * Gets the ids
      *
@@ -175,11 +188,31 @@ public class OGPGPKeyRing {
     }
 
     /**
-     * Returns whether or not this key entity is owned by the owner
+     * Returns whether or not this key entity is owned by the caller
      *
-     * @return True, if the key is owned by the owner, false if it owned by another user
+     * @return True, if the key is owned by the caller, false if it owned by another user
      */
     public boolean isOwned() {
         return this.owned;
     }
+
+    /**
+     * Sets whether or not this key entity is owned by the calling user
+     *
+     * @param owned True, if the key is owned by the calling user, false otherwise
+     * @return this
+     */
+    public OGPGPKeyRing isOwned(boolean owned) {
+       this.owned = owned;
+       return this;
+    }
+
+
+    public void setVerified (boolean verified) {
+        this.verified = verified;
+    }
+
+    public boolean isVerified() {
+        return this.verified;
+    }
 }
