@@ -76,7 +76,7 @@ public class AccountCreationServiceImpl implements AccountCreationService {
         // When creating a new key for a recipient, we will always create a recovery in case of lost email, etc
         final boolean createRecovery = true;
         final boolean markNewKeyAsCurrent = true;
-        final String newRandomPassword = cipherService.generateRandomPassword();
+        final String newRandomPassword = cipherService.generateRandomPassword(recipKey.getUserid(), recipKey.getCid());
         //Create
         GuardKeys keys = keyCreationService.create(recipKey.getUserid(),
                                                    recipKey.getCid(),
@@ -92,7 +92,7 @@ public class AccountCreationServiceImpl implements AccountCreationService {
         keyService.setCurrentKey(keys);
 
         //Setting the created keys and return them
-        recipKey.setPGPPrivateKeyRing(keys.getPGPPublicKeyRing());
+        recipKey.setPGPPublicKeyRing(keys.getPGPPublicKeyRing());
         recipKey.setPubkey(keys.getPublicKey());
         if (recipKey.isGuest()) {
             recipKey.setUserid(keys == null ? -1 : keys.getUserid());
