@@ -73,6 +73,7 @@ import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
+import com.openexchange.session.Origin;
 import com.openexchange.session.Session;
 
 /**
@@ -223,6 +224,11 @@ public class ContactKeyServiceImpl implements ContactKeyService {
             public boolean containsParameter(String name) {
                 return parameters.containsKey(name);
             }
+
+            @Override
+            public Origin getOrigin() {
+                return null;
+            }
         };
     }
 
@@ -259,6 +265,15 @@ public class ContactKeyServiceImpl implements ContactKeyService {
         }
         return emails.stream().distinct().collect(Collectors.toList());
     }
+
+    private OGPGPKeyRing toOGPGPKeyRing(int userId, int contextId, GuardKeys key) throws IOException, OXException {
+        final boolean isGuardKey = true;
+        final boolean isOwned = key.getUserid() == userId && key.getContextid() == contextId;
+        return new OGPGPKeyRing(
+            getKeyIdsString(key),
+            PGPPublicKeyRingFactory.create(KeyExportUtil.export(key.getPGPPublicKeyRing())),
+            isGuardKey).isOwned(isOwned);
+    }
     /*
      * (non-Javadoc)
      *
@@ -268,15 +283,12 @@ public class ContactKeyServiceImpl implements ContactKeyService {
     public List<OGPGPKeyRing> getKeysForContact(int userId, int contextId, String contact_id, String folder_id) throws OXException {
         Contact contact = contactService.getContact(createaFakeSession(userId, contextId), folder_id, contact_id);
         List<String> emails = getContactEmails(contact);
-        final boolean isGuardKey = true;
         List<OGPGPKeyRing> ret = emails.isEmpty() ? Collections.emptyList() : this.externalKeyService.get(userId, contextId, emails);
-
         try {
             for (String email : emails) {
                 GuardKeys key = keyService.getKeys(email);
                 if (key != null) {
-                    ret.add(new OGPGPKeyRing(getKeyIdsString(key), PGPPublicKeyRingFactory.create(KeyExportUtil.export(key.getPGPPublicKeyRing())),
-                        isGuardKey));
+                    ret.add(toOGPGPKeyRing(userId, contextId, key));
                 }
             }
         } catch (IOException e) {
