@@ -58,7 +58,6 @@ import com.openexchange.guard.hkpclient.services.RemoteKeyResult;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.services.lookup.AbstractRecipKeyLookupStrategy;
-import com.openexchange.guard.keymanagement.services.lookup.RecipKeyLookupStrategy;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 /**
@@ -89,7 +88,7 @@ public class HKPRecipKeyLookupStrategy extends AbstractRecipKeyLookupStrategy {
     private RecipKey toRecipKey(String email, RemoteKeyResult remoteResult) {
         PGPPublicKeyRing publicKeyRing = remoteResult.getRing();
         RecipKey recipKey = new RecipKey(remoteResult.getSource());
-        recipKey.setPGPPrivateKeyRing(publicKeyRing);
+        recipKey.setPGPPublicKeyRing(publicKeyRing);
         recipKey.setEmail(email);
         recipKey.setPgp(true);
         recipKey.setExpired(PGPKeysUtil.checkAllExpired(publicKeyRing));
