@@ -92,7 +92,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             key.setMisc(resultSet.getString("misc"));
             key.setSettings(getJson(resultSet, "settings"));
             key.setEmail(resultSet.getString("email"));
-            key.setLastup(resultSet.getDate("lastMod"));
+            key.setLastup(resultSet.getTimestamp("lastMod"));
             key.setQuestion(resultSet.getString("question"));
             key.setAnswer(resultSet.getString("answer"));
             key.setContextid(resultSet.getInt("cid"));
