@@ -54,6 +54,7 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.ListUtil;
@@ -111,6 +112,10 @@ public class OGPGPKeysStorageImpl implements OGPGPKeysStorage {
 
     @Override
     public List<OGPGPKey> getForUserByEmail(int userId, int contextId, List<String> emails) throws OXException {
+        if(emails.isEmpty()) {
+            return Collections.emptyList();
+        }
+
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
 
         GuardConnectionWrapper connectionWrapper = guardDatabaseService.getReadOnly(userId, contextId, 0);
