@@ -63,7 +63,6 @@ import javax.mail.internet.MimeMessage;
 import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPSecretKey;
 import org.json.JSONException;
-import org.json.JSONObject;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
@@ -73,6 +72,7 @@ import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.guest.GuardGuestService;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.commons.util.RecipKeyListUtils;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mime.encryptor.Encryptor;
@@ -150,6 +150,11 @@ public class PGPGuestEncryptor extends Encryptor {
     private byte[] encrypt() throws OXException, JSONException, IOException, MessagingException {
         MimeMessage message = msg.getMessage();
         MimeMessage encryptedMessage = null;
+
+        List<BodyPart> helpFiles = helpFileService.attachHelpFile(userid, cid) ?
+                helpFileService.getHelpFiles(userid, cid, RecipKeyListUtils.getLanguagesFor(recips)) :
+                null;
+
         if(msg.isSign()) {
             GuardKeys signingKey = getSigningKey();
             if (signingKey == null) {
@@ -157,10 +162,10 @@ public class PGPGuestEncryptor extends Encryptor {
             }
             PGPSecretKey pgpSigningKey = PGPKeysUtil.getSigningKey(signingKey.getPGPSecretKeyRing());
             char[] hashedPassword = CipherUtil.getSHA(password, signingKey.getSalt()).toCharArray();
-            encryptedMessage = this.pgpMimeService.encryptSigned(message, pgpSigningKey, hashedPassword, toPGPPublicKeys(this.recips), helpFileService.getHelpFiles(recips));
+            encryptedMessage = this.pgpMimeService.encryptSigned(message, pgpSigningKey, hashedPassword, toPGPPublicKeys(this.recips), helpFiles);
         }
         else {
-            encryptedMessage = this.pgpMimeService.encrypt(message, toPGPPublicKeys(this.recips), helpFileService.getHelpFiles(recips));
+            encryptedMessage = this.pgpMimeService.encrypt(message, toPGPPublicKeys(this.recips), helpFiles);
         }
 
 
@@ -193,7 +198,7 @@ public class PGPGuestEncryptor extends Encryptor {
 
         //Send the invitation mail
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(inviteEmail, msg.getSenderIP());
+        guardNotificationService.send(inviteEmail, userid, cid, msg.getSenderIP());
     }
 
     /**
@@ -203,7 +208,7 @@ public class PGPGuestEncryptor extends Encryptor {
      */
     private void inviteGuests(int templateId) throws OXException {
         GuardConfigurationService guardConfigurationService = Services.getService(GuardConfigurationService.class);
-        if (guardConfigurationService.getBooleanProperty(GuardProperty.newGuestsRequirePassword)) {
+        if (guardConfigurationService.getBooleanProperty(GuardProperty.newGuestsRequirePassword, userid, cid)) {
             for (final RecipKey recipient : recips) {
                 //Check for new guests
                 if (recipient.isGuest() && recipient.getNewGuestPass() != null && !recipient.getNewGuestPass().isEmpty()) {
@@ -282,7 +287,7 @@ public class PGPGuestEncryptor extends Encryptor {
             storeEmail(id, recip, encrypted);
 
             GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-            guardNotificationService.send(email, bpAttachments, "", cid, recip.getLang(), messageId, msg.getSenderIP());
+            guardNotificationService.send(email, bpAttachments, "", userid, cid, recip.getLang(), messageId, msg.getSenderIP());
         }
         return true;
     }
@@ -305,8 +310,8 @@ public class PGPGuestEncryptor extends Encryptor {
      */
     protected String getMessageID() throws OXException {
         final GuardConfigurationService guardConfigurationService = Services.getService(GuardConfigurationService.class);
-        String mailIdDomain = guardConfigurationService.getProperty(GuardProperty.mailIdDomain);
-        final String oxURL = guardConfigurationService.getProperty(GuardProperty.externalEmailURL);
+        String mailIdDomain = guardConfigurationService.getProperty(GuardProperty.mailIdDomain, userid, cid);
+        final String oxURL = guardConfigurationService.getProperty(GuardProperty.externalEmailURL, userid, cid);
         if (mailIdDomain.equals("")) {  // If maildomain not defined, try to extract domain from URL
             if (oxURL.contains("/")) {
                 mailIdDomain = oxURL.substring(0, oxURL.indexOf("/"));
