@@ -51,7 +51,6 @@ package com.openexchange.guard.mime.encryptor.pgp.impl;
 
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 import javax.mail.Message;
 import javax.mail.MessagingException;
@@ -63,6 +62,8 @@ import org.json.JSONException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.autocrypt.AutoCryptService;
+import com.openexchange.guard.common.util.GuardMimeHeaders;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.email.storage.ogEmail.Email;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
@@ -109,16 +110,17 @@ public class PGPProcessMime implements ProcessMime {
     private final GuardConfigurationService guardConfigurationService;
     private final GuardGuestEMailMetadataService guardMetaDataService;
     private final EmailStorage emailStorage;
+    private final AutoCryptService autocryptService;
 
-    private HelpFileService helpFileService;
+    private final HelpFileService helpFileService;
 
-    private PGPMimeService pgpMimeService;
+    private final PGPMimeService pgpMimeService;
 
-    private GuardNotificationService guardNotificationService;
+    private final GuardNotificationService guardNotificationService;
 
-    private GuardGuestService guestService;
+    private final GuardGuestService guestService;
 
-    private MailCreatorService mailCreatorService;
+    private final MailCreatorService mailCreatorService;
 
     /**
      * Initializes a new {@link PGPProcessMime}.
@@ -134,7 +136,8 @@ public class PGPProcessMime implements ProcessMime {
                           GuardNotificationService guardNotificationService,
                           GuardGuestEMailMetadataService guardMetaDataService,
                           EmailStorage emailStorage,
-                          MailCreatorService mailCreatorService) {
+                          MailCreatorService mailCreatorService,
+                          AutoCryptService autocryptService) {
         this.pgpCryptoService = pgpCryptoService;
         this.pgpMimeService = pgpMimeService;
         this.pgpMimeCryptoService = pgpMimeCryptoService;
@@ -145,6 +148,7 @@ public class PGPProcessMime implements ProcessMime {
         this.guardMetaDataService = guardMetaDataService;
         this.emailStorage = emailStorage;
         this.mailCreatorService = mailCreatorService;
+        this.autocryptService = autocryptService;
 
     }
 
@@ -202,6 +206,13 @@ public class PGPProcessMime implements ProcessMime {
             if (recipParse.isInline() || msg.isInline()) {
                 encryptor = new PGPInlineEncryptor(pgpCryptoService, msg, recips, userId, contextId, password);
             } else {
+                if (!msg.isDraft() && autocryptService != null) {  // For emails being sent, attach all gossip headers
+                    String autocryptHeader = autocryptService.getOutgoingHeaderString(userId, contextId, null);
+                    if (autocryptHeader != null && !autocryptHeader.isEmpty()) {
+                        msg.getMessage().addHeader("Autocrypt", autocryptHeader);
+                    }
+                    msg.setMessage(autocryptService.addGossipHeaders(msg.getMessage(), userId, contextId, allRecipts));
+                }
                 if (recips.size() > 0) {
                     encryptor = new GuardPGPMimeEncryptor(pgpCryptoService, helpFileService, msg, recips, userId, contextId, password);
                 } else {
@@ -216,7 +227,7 @@ public class PGPProcessMime implements ProcessMime {
 
                 if(msg.senderIsGuest() && !msg.isDraft()) {
                     //Sending on behalf of a guest
-                    send(encryptedResult, msg.getSenderEmail(), contextId, recips, msg.getSenderIP());
+                    send(encryptedResult, msg.getSenderEmail(), userId, contextId, recips, msg.getSenderIP());
 
                     //Remove the all recipients handled by Guard
                     return convertToString(removeRecipients(encryptedResult, allRecipts, origMessageID));
@@ -234,10 +245,10 @@ public class PGPProcessMime implements ProcessMime {
         }
     }
 
-    private void send(Message message, String senderEmail, int senderCid, ArrayList<RecipKey> recipients, String remoteIp) throws OXException {
+    private void send(Message message, String senderEmail, int userId, int senderCid, ArrayList<RecipKey> recipients, String remoteIp) throws OXException {
         String fromAddress = getFromEmailAddress(recipients, senderEmail);
         for(RecipKey recipient : recipients) {
-            this.guardNotificationService.sendMessage(message, fromAddress, senderCid, recipient.getLang(), remoteIp);
+            this.guardNotificationService.sendMessage(message, fromAddress, userId, senderCid, recipient.getLang(), remoteIp);
         }
     }
 
@@ -382,7 +393,7 @@ public class PGPProcessMime implements ProcessMime {
         for (RecipKey key : recipients) {
             message.addHeader("Remove-recip", key.getEmail());
         }
-        message.removeHeader("X-OxGuard-PIN");  // Remove record of pin from non-encrypted email
+        message.removeHeader(GuardMimeHeaders.X_GUARD_PIN);  // Remove record of pin from non-encrypted email
         message.saveChanges();
         if (origMessageID != null) {  // Save changes and enryption may change messageID.  Restore original here
             message.setHeader("Message-ID", origMessageID);
