@@ -116,18 +116,18 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     private static Logger LOG = LoggerFactory.getLogger(GuardNotificationServiceImpl.class);
 
     @Override
-    public void send(final JsonObject email, final String senderIp) throws OXException {
-        send(email, null, "", 0, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(), senderIp);
+    public void send(final JsonObject email, int senderUserId, int senderCid, final String senderIp) throws OXException {
+        send(email, null, "", senderUserId, senderCid, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(senderUserId, senderCid), senderIp);
     }
 
     @Override
-    public void send(final JsonObject email, String lang, final String senderIp) throws OXException {
-        send (email, null, "", 0, lang, getMessageID(), senderIp);
+    public void send(final JsonObject email, int senderUserId, int senderCid, String lang, final String senderIp) throws OXException {
+        send (email, null, "", senderUserId, senderCid, lang, getMessageID(senderUserId, senderCid), senderIp);
     }
 
     @Override
-    public void send(final JsonObject email, final List<BodyPart> attachments, final String senderIp) throws OXException {
-        send(email, attachments, "", 0, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(), senderIp);
+    public void send(final JsonObject email, final List<BodyPart> attachments, int senderUserId, int senderCid, final String senderIp) throws OXException {
+        send(email, attachments, "", senderUserId, senderCid,  guardConfigService.getProperty(GuardProperty.defaultLanguage, senderUserId, senderCid), getMessageID(senderUserId, senderCid), senderIp);
     }
 
     private boolean isLocal (int cid) {
@@ -135,9 +135,9 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     }
 
     @Override
-    public void send(JsonObject email, final List<BodyPart> attachments, final String sender, int senderCid, final String lang, final String messageId, String senderIp) throws OXException {
+    public void send(JsonObject email, final List<BodyPart> attachments, final String sender, int senderUserId, int senderCid, final String lang, final String messageId, String senderIp) throws OXException {
         try {
-            final Session session = getSession(isLocal(senderCid));
+            final Session session = getSession(senderUserId, senderCid, isLocal(senderCid));
             final MimeMessage message = new MimeMessage(session);
             email = email.get("data").getAsJsonObject();
             // Parse Json for email headers
@@ -323,8 +323,8 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     }
 
     @Override
-    public void sendMessage(final Message msg, final String sender, int senderCid, final String lang, final String senderIp) throws OXException {
-        final Session session = getSession(isLocal(senderCid));
+    public void sendMessage(final Message msg, final String sender, int senderUserId, int senderCid, final String lang, final String senderIp) throws OXException {
+        final Session session = getSession(senderUserId, senderCid, isLocal(senderCid));
         Transport transport;
         try {
             if (!sender.equals("")) {
@@ -368,10 +368,10 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
      * @return a javax.mail.Session
      * @throws OXException if the GuardConfigurationService is absent
      */
-    private Session getSession(boolean local) throws OXException {
-        final String server = guardConfigService.getProperty(GuardProperty.guestSMTPServer);
-        final int port = guardConfigService.getIntProperty(GuardProperty.guestSMTPPort);
-        final String username = guardConfigService.getProperty(GuardProperty.guestSMTPUsername);
+    private Session getSession(int userId, int cid, boolean local) throws OXException {
+        final String server = guardConfigService.getProperty(GuardProperty.guestSMTPServer, userId, cid);
+        final int port = guardConfigService.getIntProperty(GuardProperty.guestSMTPPort, userId, cid);
+        final String username = guardConfigService.getProperty(GuardProperty.guestSMTPUsername, userId, cid);
 
         final Properties prop = new Properties();
         boolean authenticate = true;
@@ -381,26 +381,26 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         } else {
             prop.put("mail.smtp.auth", "true");
         }
-        prop.put("mail.smtp.host", guardConfigService.getProperty(GuardProperty.guestSMTPServer));
-        prop.put("mail.smtp.port", guardConfigService.getIntProperty(GuardProperty.guestSMTPPort));
-        if (guardConfigService.getBooleanProperty(GuardProperty.useStartTLS)) {
+        prop.put("mail.smtp.host", guardConfigService.getProperty(GuardProperty.guestSMTPServer, userId, cid));
+        prop.put("mail.smtp.port", guardConfigService.getIntProperty(GuardProperty.guestSMTPPort, userId, cid));
+        if (guardConfigService.getBooleanProperty(GuardProperty.useStartTLS, userId, cid)) {
             prop.put("mail.smtp.starttls.enable", "true");
         }
         // Bug 55211, add guestSMTPMailFrom only for replies/system emails.
         if (!local) {
-            String mailFrom = guardConfigService.getProperty(GuardProperty.guestSMTPMailFrom);
+            String mailFrom = guardConfigService.getProperty(GuardProperty.guestSMTPMailFrom, userId, cid);
             if (mailFrom != null && !mailFrom.isEmpty()) {
                 prop.put("mail.smtp.from", mailFrom);
             }
         }
-        LOG.debug("Using SMTP server " + server + ":" + port + ", TLS=" + guardConfigService.getBooleanProperty(GuardProperty.useStartTLS));
+        LOG.debug("Using SMTP server " + server + ":" + port + ", TLS=" + guardConfigService.getBooleanProperty(GuardProperty.useStartTLS, userId, cid));
         Session session = null;
         if (authenticate) {
             session = Session.getInstance(prop, new Authenticator() {
 
                 @Override
                 protected PasswordAuthentication getPasswordAuthentication() {
-                    return new PasswordAuthentication(username, guardConfigService.getProperty(GuardProperty.guestSMTPPassword));
+                    return new PasswordAuthentication(username, guardConfigService.getProperty(GuardProperty.guestSMTPPassword, userId, cid));
                 }
             });
         } else {
@@ -475,9 +475,9 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
      *
      * @return the message identifier
      */
-    protected String getMessageID() {
-        String mailIdDomain = guardConfigService.getProperty(GuardProperty.mailIdDomain);
-        final String oxURL = guardConfigService.getProperty(GuardProperty.externalEmailURL);
+    protected String getMessageID(int userId, int cid) {
+        String mailIdDomain = guardConfigService.getProperty(GuardProperty.mailIdDomain, userId, cid);
+        final String oxURL = guardConfigService.getProperty(GuardProperty.externalEmailURL, userId, cid);
         if (mailIdDomain.equals("")) {  // If maildomain not defined, try to extract domain from URL
             if (oxURL.contains("/")) {
                 mailIdDomain = oxURL.substring(0, oxURL.indexOf("/"));
