@@ -193,9 +193,11 @@ public class Api {
             BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
             try {
                 String json = reader.readLine();
-                JsonParser parser = new JsonParser();
-                JsonObject result = (JsonObject) parser.parse(json);
-                this.session = result.get("session").getAsString();
+                if (json != null) {
+                    JsonParser parser = new JsonParser();
+                    JsonObject result = (JsonObject) parser.parse(json);
+                    this.session = result.get("session").getAsString();
+                }
             } finally {
                 reader.close();
                 request.releaseConnection();
@@ -312,7 +314,7 @@ public class Api {
         try {
             String json = reader.readLine();
             JsonParser parser = new JsonParser();
-            result = (JsonObject) parser.parse(json);
+            result = (JsonObject) parser.parse(json == null ? "" : json);
         } finally {
             if (reader != null) {
                 reader.close();
@@ -372,7 +374,6 @@ public class Api {
      * Multipart post for email
      */
     private JsonObject multipartPost(String params, HttpEntity entity) throws ClientProtocolException, IOException, OXException {
-        long start = System.currentTimeMillis();
         if (httpClient == null) {
             HttpConnectionPoolService poolService = Services.getService(HttpConnectionPoolService.class);
             httpClient = poolService.getCookielessClient();
@@ -400,6 +401,10 @@ public class Api {
             }
             HttpClientUtils.closeQuietly(response);
             postRequest.releaseConnection();
+            if (json == null) {
+                LOG.error("Error working on multipart post, null JSON response");
+                return null;
+            }
             if (json.contains("{")) {
                 int i = json.indexOf("{");
                 int j = json.lastIndexOf("}");
@@ -961,7 +966,13 @@ public class Api {
                 return (json.get("data").getAsJsonObject().get("defaultaddress").getAsString());
             } else {
                 json = getUserData(0);
-                return (json.get("data").getAsJsonObject().get("email1").getAsString());
+                if (json != null && json.has("data")) {
+                    return (json.get("data").getAsJsonObject().get("email1").getAsString());
+                } else {
+                    LOG.error("Error getting primary email address ");
+                    return ("");
+                }
+
             }
         } catch (Exception e) {
             LOG.error("Error getting primary email address ", e);
@@ -1007,6 +1018,10 @@ public class Api {
         if (i > 0) {
             try {
                 String defaultDraft = getConfig("mail/folder/drafts");
+                if (defaultDraft == null) {
+                    LOG.error("Problem getting draft folder");
+                    return;
+                }
                 JsonParser parser = new JsonParser();
                 JsonObject draft = (JsonObject) parser.parse(defaultDraft);
                 String id = msgref.substring(i + 1);
