@@ -58,7 +58,7 @@ import java.util.Date;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.utils.DBUtils;
-import com.openexchange.guard.session.exceptions.GuardSessionExceptionCodes;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.session.osgi.Services;
 
 /**
@@ -95,7 +95,7 @@ public class GuardSessionStorageImpl implements GuardSessionStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardSessionExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -119,7 +119,7 @@ public class GuardSessionStorageImpl implements GuardSessionStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardSessionExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -137,7 +137,7 @@ public class GuardSessionStorageImpl implements GuardSessionStorage {
             stmt.setString(1, sessionId);
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardSessionExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
@@ -156,7 +156,7 @@ public class GuardSessionStorageImpl implements GuardSessionStorage {
             stmt.setLong(1, seconds);
             return stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardSessionExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForGuard(connection);
