@@ -79,11 +79,12 @@ public interface FileCacheStorage {
     /**
      * Gets a list of items for a given user
      * @param userId The user ID
+     * @param cid The contextId
      * @param offset The offset from where to return the items (depends on the underlying sorting)
      * @param maxCount the maximum amount of returned items
      * @return A list of items for the given user which contains not more than <code>maxCount</code> items.
      */
-    List<FileCacheItem> getForUser(int userId, int offset, int maxCount) throws OXException;
+    List<FileCacheItem> getForUser(int userId, int cid, int offset, int maxCount) throws OXException;
 
     /**
      * Creates a new FileCache item
@@ -126,6 +127,6 @@ public interface FileCacheStorage {
      * @return
      * @throws OXException
      */
-    List<FileCacheItem> findAllForUser (int userId) throws OXException;
+    List<FileCacheItem> findAllForUser (int userId, int cid) throws OXException;
 
 }
