@@ -57,22 +57,38 @@ import java.util.ArrayList;
 import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.database.GuardDatabaseService;
+import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.database.utils.DBUtils;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheItem;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
 import com.openexchange.guard.storage.osgi.Services;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link FileCacheStorageImpl} provides a REST DB implementation of the FileCacheStorage
  */
 public class FileCacheStorageImpl implements FileCacheStorage {
 
+    private final ServiceLookup lookup;
+
     /**
      * Initialises a new {@link FileCacheStorageImpl}.
      */
-    public FileCacheStorageImpl() {
+    public FileCacheStorageImpl(ServiceLookup lookup) {
         super();
+        this.lookup = lookup;
+    }
+
+    private String getStoragePrefix (int userId, int cid) throws OXException {
+        Storage currentStorage = lookup.getService(Storage.class);
+        GuardShardingService shardingService = lookup.getService(GuardShardingService.class);
+        if (currentStorage == null || shardingService == null) {
+            return "";
+        }
+        int shard = shardingService.getShard(userId, cid);
+        return currentStorage.getDirectoryPrefix(userId, 0, shard);
     }
 
     @Override
@@ -132,7 +148,7 @@ public class FileCacheStorageImpl implements FileCacheStorage {
      * @see com.openexchange.guard.storage.cache.FileCacheStorage#getForUser(int, int, int)
      */
     @Override
-    public List<FileCacheItem> getForUser(int userId, int offset, int maxCount) throws OXException {
+    public List<FileCacheItem> getForUser(int userId, int cid, int offset, int maxCount) throws OXException {
         List<FileCacheItem> ret = new ArrayList<FileCacheItem>();
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         Connection connection = guardDatabaseService.getReadOnlyForGuard();
@@ -146,8 +162,13 @@ public class FileCacheStorageImpl implements FileCacheStorage {
             stmt.setInt(3, offset);
             resultSet = stmt.executeQuery();
 
+            String filePrefix = getStoragePrefix(userId, cid);
             while (resultSet.next()) {
-                ret.add(new FileCacheItem(resultSet.getString(1), resultSet.getInt(2), resultSet.getString(3), resultSet.getDate(4)));
+                String path = resultSet.getString("location");
+                if (path.startsWith(filePrefix)) {
+                    ret.add(new FileCacheItem(resultSet.getString(1), resultSet.getInt(2), resultSet.getString(3), resultSet.getDate(4)));
+                }
+
             }
             return ret;
         } catch (SQLException e) {
@@ -244,7 +265,7 @@ public class FileCacheStorageImpl implements FileCacheStorage {
      * @see com.openexchange.guard.storage.cache.FileCacheStorage#findAllForUser(int)
      */
     @Override
-    public List<FileCacheItem> findAllForUser(int userId) throws OXException {
+    public List<FileCacheItem> findAllForUser(int userId, int cid) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
         Connection connection = guardDatabaseService.getReadOnlyForGuard();
 
@@ -256,9 +277,12 @@ public class FileCacheStorageImpl implements FileCacheStorage {
             stmt = connection.prepareStatement(FileCacheSql.SELECT_BY_USER);
             stmt.setInt(1, userId);
             resultSet = stmt.executeQuery();
-
+            String filePrefix = getStoragePrefix(userId, cid);
             while (resultSet.next()) {
-                ret.add(new FileCacheItem(resultSet.getString(1), resultSet.getInt(2), resultSet.getString(3), resultSet.getDate(4)));
+                String path = resultSet.getString("location");
+                if (path.startsWith(filePrefix)) {
+                    ret.add(new FileCacheItem(resultSet.getString(1), resultSet.getInt(2), resultSet.getString(3), resultSet.getDate(4)));
+                }
             }
         } catch (SQLException e) {
             throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
