@@ -53,9 +53,12 @@ import org.slf4j.Logger;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.KeyCreationService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.settings.GlobalSettingsStorage;
 import com.openexchange.guard.update.GuardUpdateService;
+import com.openexchange.guard.update.internal.GuardKeysUpdater;
 import com.openexchange.guard.update.internal.GuardUpdateServiceImpl;
+import com.openexchange.guard.update.keys.MissingPGPPreferences;
 import com.openexchange.osgi.HousekeepingActivator;
 
 /**
@@ -71,7 +74,8 @@ public class UpdateActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GlobalSettingsStorage.class, GuardConfigurationService.class, GuardMasterKeyService.class, KeyCreationService.class };
+        return new Class<?>[] { GlobalSettingsStorage.class, GuardConfigurationService.class, GuardMasterKeyService.class,
+            KeyCreationService.class, KeyTableStorage.class };
     }
 
     /**
@@ -84,6 +88,9 @@ public class UpdateActivator extends HousekeepingActivator {
 
         Services.setServiceLookup(this);
 
+        GuardKeysUpdater updater = new GuardKeysUpdater(this.getService(KeyTableStorage.class))
+            .addUpgradeService(new MissingPGPPreferences(this.getService(KeyTableStorage.class)));
+        registerService(GuardKeysUpdater.class, updater);
         registerService(GuardUpdateService.class, new GuardUpdateServiceImpl());
     }
 
