@@ -118,7 +118,7 @@ public class GuestCleanupTask implements Runnable {
         //Remove the unused fileCache items from the storages
         for (OXGuardUser user : users) {
             try {
-                List<FileCacheItem> items = fileCacheStorage.findAllForUser(user.getId());
+                List<FileCacheItem> items = fileCacheStorage.findAllForUser(user.getId(), user.getContextId());
                 for (FileCacheItem fileCacheItem: items) {
                     //Remove from the file storage
                     Storage storage = Services.getService(Storage.class);
