@@ -238,16 +238,18 @@ public class GuardErrorResponseRenderer {
                     //It's possible that the underlying logic did not use getWriter() but getOutputStream(); And only one is allowed.
                     writer = new PrintWriter(new OutputStreamWriter(response.getOutputStream(), response.getCharacterEncoding()));
                 } finally {
-                    writer.write(JS_FRAGMENT_PART1);
-                    writer.write(callback);
-                    writer.write(JS_FRAGMENT_PART2);
-                    writer.write(callback);
-                    writer.write("\"])(");
-                    writer.write(errorObject.toString());
-                    writer.write(JS_FRAGMENT_PART3);
+                    if (writer != null) {
+                        writer.write(JS_FRAGMENT_PART1);
+                        writer.write(callback);
+                        writer.write(JS_FRAGMENT_PART2);
+                        writer.write(callback);
+                        writer.write("\"])(");
+                        writer.write(errorObject.toString());
+                        writer.write(JS_FRAGMENT_PART3);
+                    }
                 }
             } finally {
-                writer.close();
+                if (writer != null) writer.close();
             }
         } else {
             //Writing error as plain JSON
