@@ -70,4 +70,6 @@ class Parameters {
     public static final String PARAM_INLINE = "inline";
     public static final String PARAM_REASON = "reason";
     public static final String PARAM_SUBKEYS = "subkeys";
+    public static final String PARAM_VERIFIED = "verified";
+    public static final String PARAM_AUTOCRYPT = "autocrypt";
 }
