@@ -76,7 +76,7 @@ public class SetCurrentKeyAction extends GuardServletAction {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         GuardKeys keys = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
         if(keys != null) {
-            keyService.setCurrentKey(userSession.getGuardUserId(), userSession.getGuardContextId(), keys);
+            keyService.setCurrentKey(keys);
             ServletUtils.sendJsonOK(response, null);
         }
         else {
