@@ -68,9 +68,7 @@ import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticati
 public class PGPMailServlet extends AbstractGuardServlet {
 
     private static final long serialVersionUID = -3402143663178340210L;
-    private static final String GET_VERIFY_EMAIL_SIGNATURE = "verify";
     private static final String GET_PUBLIC_KEY_FROM_ATTACHMENT_ACTION = "savepublicattach";
-    private static final String GET_IMPORT_VCARD_FROM_ATTACHMENT_ACTION_ = "importvcard";
 
     private static final String POST_PROCESS_INCOMING_MIME = "process_mime";
     private static final String POST_VERIFY_MESSAGE = "verify";
@@ -90,9 +88,7 @@ public class PGPMailServlet extends AbstractGuardServlet {
 
         //GET
         getActions = new HashMap<String, GuardServletAction>();
-        getActions.put(GET_VERIFY_EMAIL_SIGNATURE, new VerifyEmailSignatureAction().setAuthenticationHandler(userSessionAuthenticationHandler));
         getActions.put(GET_PUBLIC_KEY_FROM_ATTACHMENT_ACTION, new GetPublicKeyFromAttachmentAction().setAuthenticationHandler(userSessionAuthenticationHandler));
-        getActions.put(GET_IMPORT_VCARD_FROM_ATTACHMENT_ACTION_, new ImportVCardAction().setAuthenticationHandler(userSessionAuthenticationHandler));
 
         //POST
         postActions = new HashMap<String, GuardServletAction>();
@@ -108,8 +104,6 @@ public class PGPMailServlet extends AbstractGuardServlet {
             new VerifyMimeEmailAction()
                 .setAuthenticationHandler(basicAuthAuthenticationHandler)
                 .setErrorResponseRenderer(new GuardErrorResponseRenderer(HttpServletResponse.SC_INTERNAL_SERVER_ERROR)));
-
-
     }
 
 
