@@ -55,8 +55,8 @@ import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
-import com.openexchange.guard.user.GuardUser;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXUser;
+import com.openexchange.guard.user.OXUserService;
 
 /**
  * Checks if the OX backend's REST-API is available
@@ -71,8 +71,8 @@ public class PingAction extends GuardServletAction {
         if(userSession == null) {
             ServletUtils.sendHtmlOK(response, "OK - [No logged in]");
         } else {
-            GuardUserService userService = Services.getService(GuardUserService.class);
-            GuardUser user = userService.getUser(userSession.getContextId(), userSession.getUserId());
+            OXUserService userService = Services.getService(OXUserService.class);
+            OXUser user = userService.getUser(userSession.getContextId(), userSession.getUserId());
             if(user != null) {
                 ServletUtils.sendHtmlOK(response, "OK - " + user.getEmail());
             }
