@@ -7,6 +7,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.activity.ActivityTrackingService;
+import com.openexchange.guard.autocrypt.database.AutoCryptStorageService;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.guest.metadata.storage.GuardGuestEMailMetadataService;
 import com.openexchange.guard.guest.redirector.GuestRedirectorService;
@@ -68,6 +69,14 @@ public class UserDeleter {
         }
     }
 
+    private void removeAutocrypt(int userId, int contextId) throws OXException {
+        if (contextId < 0) {
+            return;
+        }
+        AutoCryptStorageService autocryptStorage = Services.getService(AutoCryptStorageService.class);
+        autocryptStorage.deleteAllForUser(userId, contextId);
+    }
+
     private void deleteGuestData(int userId, int contextId) throws OXException {
         // Cleanup metadata
         GuardGuestEMailMetadataService guestMetaService = Services.getService(GuardGuestEMailMetadataService.class);
@@ -75,7 +84,7 @@ public class UserDeleter {
         // Cleanup file cache
         FileCacheStorage fileStorage = Services.getService(FileCacheStorage.class);
         Storage storage = Services.getService(Storage.class);
-        List<FileCacheItem> items = fileStorage.findAllForUser(userId);
+        List<FileCacheItem> items = fileStorage.findAllForUser(userId, contextId);
         for (FileCacheItem item: items) {
             try {
                 storage.deleteEncrObj(item.getLocation());
@@ -157,6 +166,7 @@ public class UserDeleter {
      * @throws OXException
      */
     private void performDelete(int userId, int contextId) throws OXException {
+        removeAutocrypt(userId, contextId);
         if (contextId < 0) {
             deleteGuestData(userId, contextId);
         }
@@ -164,6 +174,9 @@ public class UserDeleter {
         removeEmailMappings(userId, contextId);
         // Cleanup any activity tracking
         ActivityTrackingService activityTracker = Services.getServiceLookup().getOptionalService(ActivityTrackingService.class);
-        if (activityTracker != null) activityTracker.removeActivityRecord(userId, contextId);
+        if (activityTracker != null) {
+            activityTracker.removeActivityRecord(userId, contextId);
+        }
+
     }
 }
